@@ -29,7 +29,6 @@ $mirrors = {
     },
     'India' => {
       'http://ctan.imsc.res.in/' => 1,
-      'http://mirror.iopb.res.in/tex-archive/' => 1,
     },
     'Indonesia' => {
       'https://mirror.unpad.ac.id/ctan/' => 1,
@@ -105,6 +104,8 @@ $mirrors = {
       'https://ftp.rrze.uni-erlangen.de/ctan/' => 1,
       'https://ftp.rrzn.uni-hannover.de/pub/mirror/tex-archive/' => 1,
       'https://ftp.tu-chemnitz.de/pub/tex/' => 1,
+      'https://mirror.clientvps.com/CTAN/' => 1,
+      'https://mirror.dogado.de/tex-archive/' => 1,
       'https://mirror.informatik.hs-fulda.de/tex-archive/' => 1,
       'https://packages.oth-regensburg.de/ctan/' => 1,
     },
@@ -128,7 +129,7 @@ $mirrors = {
       'https://ctan.uib.no/' => 1,
     },
     'Poland' => {
-      'ftp://ftp.gust.org.pl/TeX/' => 1,
+      'https://ftp.gust.org.pl/TeX/' => 1,
       'https://sunsite.icm.edu.pl/pub/CTAN/' => 1,
     },
     'Portugal' => {
@@ -156,6 +157,7 @@ $mirrors = {
     },
     'Sweden' => {
       'https://ftp.acc.umu.se/mirror/CTAN/' => 1,
+      'https://ftpmirror1.infania.net/mirror/CTAN/' => 1,
     },
     'United Kingdom' => {
       'https://anorien.csc.warwick.ac.uk/mirrors/CTAN/' => 1,
